# Changelog

## 0.0.1-alpha.1 (2024-11-16)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/TralahM/paymaxis-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([bbff90c](https://github.com/TralahM/paymaxis-python/commit/bbff90c7bf8f383e7d20f7aae1eb8f5eece65e18))
* update SDK settings ([#2](https://github.com/TralahM/paymaxis-python/issues/2)) ([9372c1a](https://github.com/TralahM/paymaxis-python/commit/9372c1abbbbdbc2a3a230d20e5db31ee24a2fa6f))
